@@ -36,6 +36,30 @@ TOPIC_CHOICES = (
     ('easier', 'I have an idea how make a certain task easier to do'),
 )
 
+pnp_loglevel_choices = [
+    ('0', '0 - Only Errors'),
+    ('1', '1 - Little logging'),
+    ('2', '2 - Log Everything'),
+    ('-1', '-1 Debug mode (log all and slower processing')
+]
+pnp_log_type_choices = [('syslog', 'syslog'), ('file', 'file')]
+
+COMMAND_CHOICES = [('reload', 'reload'), ('status', 'status'),
+                   ('restart', 'restart'), ('stop', 'stop'), ('start', 'start')]
+
+
+initial_paste = """
+define service {
+    host_name  host01.example.com
+    service_description http://host01.example.com
+    use     template-http
+}
+
+define service {
+    name        template-http
+    check_command   okc-check_http
+}
+"""
 
 class ContactUsForm(forms.Form):
     topic = forms.ChoiceField(choices=TOPIC_CHOICES)
@@ -79,6 +103,10 @@ class AdagiosSettingsForm(forms.Form):
         help_text="Path to you nagios init script. Adagios will use this when stopping/starting/reloading nagios")
     nagios_binary = forms.CharField(
         help_text="Path to you nagios daemon binary. Adagios will use this to verify config with 'nagios -v nagios_config'")
+    livestatus_path = forms.CharField(
+        help_text="Path to MK Livestatus socket. If left empty Adagios will try to autodiscover from your nagios.cfg",
+        required=False,
+    )
     enable_githandler = forms.BooleanField(
         required=False, initial=settings.enable_githandler, help_text="If set. Adagios will commit any changes it makes to git repository.")
     enable_loghandler = forms.BooleanField(
@@ -89,6 +117,9 @@ class AdagiosSettingsForm(forms.Form):
     enable_status_view = forms.BooleanField(
         required=False, initial=settings.enable_status_view,
         help_text="If set. Enable status view which is an alternative to nagios legacy web interface. You will need to restart web server for the changes to take effect")
+    auto_reload = forms.BooleanField(
+        required=False, initial=settings.auto_reload,
+        help_text="If set. Nagios is reloaded automatically after every change.")
     warn_if_selinux_is_active = forms.BooleanField(
         required=False, help_text="Adagios does not play well with SElinux. So lets issue a warning if it is active. Only disable this if you know what you are doing.")
     pnp_filepath = forms.CharField(
@@ -174,10 +205,10 @@ class EditAllForm(forms.Form):
         self.attribute = attribute
         self.new_value = new_value
         super(self.__class__, self).__init__(self, args, kwargs)
-        filter = {}
-        filter['object_type'] = object_type
-        filter['%s__isnot' % attribute] = new_value
-        items = Model.ObjectDefinition.objects.filter(**filter)
+        search_filter = {}
+        search_filter['object_type'] = object_type
+        search_filter['%s__isnot' % attribute] = new_value
+        items = Model.ObjectDefinition.objects.filter(**search_filter)
         interesting_objects = []
         for i in items:
             if attribute in i._defined_attributes or i.use is None:
@@ -224,14 +255,10 @@ class PNPTemplatesForm(forms.Form):
                 directory = v.strip(";").strip('"').strip("'")
                 self.template_directories.append(directory)
                 if os.path.isdir(directory):
-                    for file in os.listdir(directory):
-                        self.templates.append("%s/%s" % (directory, file))
-                        # self.templates.append(file)
+                    for f in os.listdir(directory):
+                        self.templates.append("%s/%s" % (directory, f))
 
         super(self.__class__, self).__init__(*args, **kwargs)
-pnp_loglevel_choices = [('0', '0 - Only Errors'), ('1', '1 - Little logging'), (
-    '2', '2 - Log Everything'), ('-1', '-1 Debug mode (log all and slower processing')]
-pnp_log_type_choices = [('syslog', 'syslog'), ('file', 'file')]
 
 
 class PNPConfigForm(forms.Form):
@@ -271,7 +298,9 @@ class PNPConfigForm(forms.Form):
     perfdata_file_processing_interval = forms.IntegerField(
         help_text="Interval between file processing")
 
-    def __init__(self, initial={}, *args, **kwargs):
+    def __init__(self, initial=None, *args, **kwargs):
+        if not initial:
+            initial = {}
         my_initial = {}
         # Lets use PNPBrokerModuleForm to find sensible path to npcd config
         # file
@@ -295,7 +324,9 @@ class EditFileForm(forms.Form):
     filecontent = forms.CharField(widget=forms.Textarea(
         attrs={'wrap': 'off', 'rows': '50', 'cols': '2000'}))
 
-    def __init__(self, filename, initial={}, *args, **kwargs):
+    def __init__(self, filename, initial=None, *args, **kwargs):
+        if not initial:
+            initial = {}
         self.filename = filename
         my_initial = initial.copy()
         if 'filecontent' not in my_initial:
@@ -338,7 +369,9 @@ class PNPBrokerModuleForm(forms.Form):
             raise forms.ValidationError('File not found')
         return filename
 
-    def __init__(self, initial={}, *args, **kwargs):
+    def __init__(self, initial=None, *args, **kwargs):
+        if not initial:
+            initial = {}
         my_initial = {}
         Model.config.parse()
         maincfg_values = Model.config.maincfg_values
@@ -372,7 +405,7 @@ class PNPBrokerModuleForm(forms.Form):
         for i in possible_locations:
             if os.path.isfile(i):
                 return i
-        return i
+        return possible_locations[-1]
 
     def get_suggested_npcd_path(self):
         """ Returns best guess for full path to npcd.cfg file """
@@ -382,7 +415,7 @@ class PNPBrokerModuleForm(forms.Form):
         for i in possible_locations:
             if os.path.isfile(i):
                 return i
-        return i
+        return possible_locations[-1]
 
     def save(self):
         if 'broker_module' in self.changed_data or 'config_file' in self.changed_data or self.nagios_configline is None:
@@ -415,9 +448,6 @@ class PluginOutputForm(forms.Form):
         output = Utils.PluginOutput(plugin_output)
         self.results = output
 
-COMMAND_CHOICES = [('reload', 'reload'), ('status', 'status'),
-                   ('restart', 'restart'), ('stop', 'stop'), ('start', 'start')]
-
 
 class NagiosServiceForm(forms.Form):
 
@@ -440,10 +470,12 @@ class NagiosServiceForm(forms.Form):
             command = "status"
         elif "verify" in self.data:
             command = "verify"
+        else:
+            raise Exception("Unknown command")
         self.command = command
         nagios_init = settings.nagios_init_script
         nagios_binary = settings.nagios_binary
-        nagios_config = settings.nagios_config
+        nagios_config = settings.nagios_config or pynag.Model.config.cfg_file
         if command == "verify":
             command = "%s -v '%s'" % (nagios_binary, nagios_config)
         else:
@@ -518,9 +550,15 @@ class SendEmailForm(forms.Form):
 
         cc_address = []
         from_address = self._resolve_remote_user(self.remote_user)
+        # Check if _resolve_remote_user did in fact return an email address - avoid SMTPSenderRefused.
+        import re # re built in Py1.5+
+        if re.compile('([\w\-\.]+@(\w[\w\-]+\.)+[\w\-]+)').search(from_address) is None:
+            from_address = str(from_address) + '@no.domain'
         to_address = self.cleaned_data['to']
         to_address = to_address.split(',')
         text_content = self.cleaned_data['message']
+        text_content = text_content.replace('\n','<br>')
+
         # self.html_content is rendered in misc.views.mail()
         html_content = text_content + "<p></p>" + self.html_content
         if self.cleaned_data['add_myself_to_cc']:
@@ -530,7 +568,7 @@ class SendEmailForm(forms.Form):
             self.acknowledge_all_services(comment)
             self.acknowledge_all_hosts(comment)
         # Here we actually send some email:
-        text_content = text_content.replace('\n','\r\n')
+
         msg = EmailMultiAlternatives(
             subject=subject, body=text_content, from_email=from_address, cc=cc_address, to=to_address)
         msg.attach_alternative(html_content, "text/html")
@@ -577,8 +615,8 @@ class SendEmailForm(forms.Form):
          Else if remote user is a valid email address, return that address
          Else return None
         """
-        livestatus = pynag.Parsers.mk_livestatus(
-            nagios_cfg_file=settings.nagios_config)
+        import adagios.status.utils
+        livestatus = adagios.status.utils.livestatus(request=None)
         try:
             contact = livestatus.get_contact(username)
             return "%s <%s>" % (contact.get('alias'), contact.get('email'))
@@ -587,18 +625,7 @@ class SendEmailForm(forms.Form):
             return username
 
 
-initial_paste = """
-define service {
-    host_name  host01.example.com
-    service_description http://host01.example.com
-    use     template-http
-}
 
-define service {
-    name        template-http
-    check_command   okc-check_http
-}
-"""
 
 
 class PasteForm(forms.Form):
