@@ -43,21 +43,21 @@ from adagios import __version__
 import adagios.status.utils
 
 from collections import defaultdict
-from adagios.views import error_handler, error_page
+from adagios.views import adagios_decorator, error_page
 
 state = defaultdict(lambda: "unknown")
 state[0] = "ok"
 state[1] = "warning"
 state[2] = "critical"
 
-@error_handler
+@adagios_decorator
 def index(request):
     c = {}
     c['nagios_cfg'] = pynag.Model.config.cfg_file
     c['version'] = __version__
     return render_to_response('frontpage.html', c, context_instance=RequestContext(request))
 
-
+@adagios_decorator
 def settings(request):
     c = {}
     c.update(csrf(request))
@@ -74,46 +74,20 @@ def settings(request):
                 m.append("%s successfully saved." % form.adagios_configfile)
             except IOError, exc:
                 e.append(exc)
+    else:
+        raise Exception("We only support methods GET or POST")
     c['form'] = form
     return render_to_response('settings.html', c, context_instance=RequestContext(request))
 
 
-def contact_us(request):
-    """ Bring a small form that has a "contact us" form on it """
-    c = {}
-    c.update(csrf(request))
-    if request.method == 'GET':
-        form = forms.ContactUsForm(initial=request.GET)
-    else:
-        form = forms.ContactUsForm(data=request.POST)
-        if form.is_valid():
-            form.save()
-            c['thank_you'] = True
-            c['sender'] = form.cleaned_data['sender']
-
-    c['form'] = form
-    return render_to_response('contact_us.html', c,  context_instance=RequestContext(request))
-
-
+@adagios_decorator
 def nagios(request):
     c = {}
     c['nagios_url'] = adagios.settings.nagios_url
     return render_to_response('nagios.html', c, context_instance=RequestContext(request))
 
 
-def map_view(request):
-    c = {}
-    try:
-        import pynag.Parsers
-        livestatus = pynag.Parsers.mk_livestatus()
-        c['hosts'] = livestatus.get_hosts()
-        c['map_center'] = adagios.settings.map_center
-        c['map_zoom'] = adagios.settings.map_zoom
-    except Exception:
-        pass
-    return render_to_response('map.html', c, context_instance=RequestContext(request))
-
-
+@adagios_decorator
 def gitlog(request):
     """ View that displays a nice log of previous git commits in dirname(config.cfg_file) """
     c = {}
@@ -194,6 +168,7 @@ def gitlog(request):
     return render_to_response('gitlog.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def nagios_service(request):
     """ View to restart / reload nagios service """
     c = {}
@@ -224,12 +199,13 @@ def nagios_service(request):
     elif s == 1:
         c['friendly_status'] = "not running"
     else:
-        c['friendly_status'] = 'unknown (exit status %s)' % (s)
+        c['friendly_status'] = 'unknown (exit status %s)' % (s, )
     needs_reload = pynag.Model.config.needs_reload()
     c['needs_reload'] = needs_reload
     return render_to_response('nagios_service.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def pnp4nagios(request):
     """ View to handle integration with pnp4nagios """
     c = {}
@@ -271,6 +247,7 @@ def pnp4nagios(request):
     return render_to_response('pnp4nagios.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def edit_file(request, filename):
     """ This view gives raw read/write access to a given filename.
 
@@ -293,12 +270,14 @@ def edit_file(request, filename):
     return render_to_response('editfile.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def edit_nagios_cfg(request):
     """ Allows raw editing of nagios.cfg configfile
     """
     return edit_file(request, filename=adagios.settings.nagios_config)
 
 
+@adagios_decorator
 def pnp4nagios_edit_template(request, filename):
     """ Allows raw editing of a pnp4nagios template.
 
@@ -313,6 +292,7 @@ def pnp4nagios_edit_template(request, filename):
             "Security violation. You are not allowed to edit %s" % filename)
 
 
+@adagios_decorator
 def icons(request, image_name=None):
     """ Use this view to see nagios icons/logos
     """
@@ -345,11 +325,7 @@ def icons(request, image_name=None):
             raise Exception("Not allowed to see this image")
 
 
-def sign_out(request):
-    """ Use this to force browser to update authentication """
-    return HttpResponse('You have been signed out', status=401)
-
-
+@adagios_decorator
 def mail(request):
     """ Send a notification email to one or more contacts regarding hosts or services """
     c = {}
@@ -373,6 +349,7 @@ def mail(request):
         c['form'] = forms.SendEmailForm(remote_user, data=request.POST)
         services = request.POST.getlist('service') or request.POST.getlist('service[]')
         hosts = request.POST.getlist('host') or request.POST.getlist('host[]')
+        c['acknowledged_or_not'] = request.POST.get('acknowledge_all_problems') == 'true'
 
     for host_name in hosts:
         host_object = adagios.status.utils.get_hosts(request, host_name=host_name)
@@ -415,6 +392,7 @@ def mail(request):
     return render_to_response('misc_mail.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def test(request):
     """ Generic test view, use this as a sandbox if you like
     """
@@ -433,6 +411,7 @@ def test(request):
     return render_to_response('test.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def edit_check_command(request):
     """ Generic view for editing check command of a service
     """
@@ -450,12 +429,12 @@ def edit_check_command(request):
 
     hosts = pynag.Model.Host.objects.filter(host_name=c['host_name'])
     if len(hosts) == 0:
-        c['errors'].append("Host %s was not found " % (host_name))
+        c['errors'].append("Host %s was not found " % (c['host_name']))
     services = pynag.Model.Service.objects.filter(
         host_name=c['host_name'], service_description=c['service_description'])
     if len(services) == 0:
         c['errors'].append("Service %s/%s was not found " %
-                           (host_name, service_description))
+                           (c['host_name'], c['service_description']))
     command_names = map(
         lambda x: x.get("command_name", ''), pynag.Model.Command.objects.all)
     if c['check_command'] in (None, '', 'None'):
@@ -469,6 +448,7 @@ def edit_check_command(request):
     return render_to_response('edit_check_command.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def paste(request):
     """ Generic test view, use this as a sandbox if you like
     """
@@ -485,3 +465,5 @@ def paste(request):
         c['form'] = forms.PasteForm(initial=request.GET)
 
     return render_to_response('test2.html', c, context_instance=RequestContext(request))
+
+
