@@ -23,6 +23,7 @@ from pynag.Utils import AttributeList
 from adagios.objectbrowser.help_text import object_definitions
 from pynag.Model import ObjectDefinition
 from adagios.forms import AdagiosForm
+import adagios.misc.rest
 
 
 # These fields are special, they are a comma seperated list, and may or
@@ -65,6 +66,8 @@ class PynagChoiceField(forms.MultipleChoiceField):
         """
         Changes list into a comma separated string. Removes duplicates.
         """
+        if not value:
+            return "null"
         tmp = []
         for i in value:
             if i not in tmp:
@@ -114,39 +117,51 @@ class PynagForm(AdagiosForm):
         for k, v in cleaned_data.items():
             # change from unicode to str
             v = cleaned_data[k] = smart_str(v)
-            if k in MULTICHOICE_FIELDS:
-                # Put the + back in there if needed
-                if self.pynag_object.get(k, '').startswith('+'):
-                    cleaned_data[k] = "+%s" % (v)
+
+            # Empty string, or the string None, means remove the field
+            if v in ('', 'None'):
+                cleaned_data[k] = v = None
+
+            # Maintain operator (+,-, !) for multichoice fields
+            if k in MULTICHOICE_FIELDS and v and v != "null":
+                operator = AttributeList(self.pynag_object.get(k, '')).operator or ''
+                cleaned_data[k] = "%s%s" % (operator, v)
         return cleaned_data
 
     def save(self):
         changed_keys = map(lambda x: smart_str(x), self.changed_data)
         for k in changed_keys:
-            # Ignore fields that did not appear in the POST at all
-            if k not in self.data and k not in MULTICHOICE_FIELDS:
+
+            # Ignore fields that did not appear in the POST at all EXCEPT
+            # If it it a pynagchoicefield. That is because multichoicefield that
+            # does not appear in the post, means that the user removed every attribute
+            # in the multichoice field
+            if k not in self.data and not isinstance(self.fields.get(k, None), PynagChoiceField):
                 continue
-            # If value is empty, we assume it is to be removed
+
             value = self.cleaned_data[k]
-            if value == '':
-                value = None
+
             # Sometimes attributes slide in changed_data without having
             # been modified, lets ignore those
             if self.pynag_object[k] == value:
                 continue
+
             # Multichoice fields have a special restriction, sometimes they contain
             # the same values as before but in a different order.
             if k in MULTICHOICE_FIELDS:
                 original = AttributeList(self.pynag_object[k])
                 new = AttributeList(value)
                 if sorted(original.fields) == sorted(new.fields):
-                    continue
-            # If we reach here, it is save to modify our pynag object.
+                    continue            # If we reach here, it is save to modify our pynag object.
+
+            # Here we actually make a change to our pynag object
             self.pynag_object[k] = value
+
             # Additionally, update the field for the return form
             self.fields[k] = self.get_pynagField(k, css_tag="defined")
             self.fields[k].value = value
         self.pynag_object.save()
+        adagios.misc.rest.add_notification(message="Object successfully saved", level="success", notification_type="show_once")
 
     def __init__(self, pynag_object, *args, **kwargs):
         self.pynag_object = pynag_object
@@ -163,8 +178,7 @@ class PynagForm(AdagiosForm):
         # Special hack for macros
         # If this is a post and any post data looks like a nagios macro
         # We will generate a field for it on the fly
-        macros = filter(lambda x: x.startswith(
-            '$') and x.endswith('$'), self.data.keys())
+        macros = filter(lambda x: x.startswith('$') and x.endswith('$'), self.data.keys())
         for field_name in macros:
             # if field_name.startswith('$ARG'):
             #    self.fields[field_name] = self.get_pynagField(field_name, css_tag='defined')
@@ -233,7 +247,7 @@ class PynagForm(AdagiosForm):
                 lambda x: (x.servicegroup_name, x.servicegroup_name), all_groups)
             field = PynagChoiceField(
                 choices=sorted(choices), inline_help_text="No %s selected" % (field_name))
-        elif field_name in ('hostgroups', 'hostgroup_members'):
+        elif field_name in ('hostgroups', 'hostgroup_members', 'hostgroup_name') and object_type != 'hostgroup':
             all_groups = Model.Hostgroup.objects.filter(
                 hostgroup_name__contains='')
             choices = map(
@@ -678,28 +692,34 @@ class AddObjectForm(PynagForm):
         if object_type in ('host', 'contact', 'service'):
             self.fields['use'] = self.get_pynagField('use')
             self.fields['use'].initial = str('generic-%s' % object_type)
-            self.fields[
-                'use'].help_text = "Inherit attributes from this template"
+            self.fields['use'].help_text = "Inherit attributes from this template"
         if object_type == 'host':
-            self.fields['host_name'] = self.get_pynagField(
-                'host_name', required=True)
-            self.fields['address'] = self.get_pynagField(
-                'address', required=True)
+            self.fields['host_name'] = self.get_pynagField('host_name', required=True)
+            self.fields['address'] = self.get_pynagField('address', required=True)
             self.fields['alias'] = self.get_pynagField('alias', required=False)
         elif object_type == 'service':
-            self.fields['service_description'] = self.get_pynagField(
-                'service_description', required=True)
-            self.fields['host_name'] = self.get_pynagField(
-                'host_name', required=True)
-            self.fields[
-                'host_name'].help_text = 'Tell us which host this service check will be applied to'
-            #self.fields['hostgroup_name'] = self.get_pynagField('hostgroup_name', required=False)
-            #self.fields['hostgroup_name'].help_text = "If you specify any hostgroups, this service will be applied to all hosts in that hostgroup"
+            self.fields['service_description'] = self.get_pynagField('service_description', required=True)
+            self.fields['host_name'] = self.get_pynagField('host_name', required=False)
+            self.fields['host_name'].help_text = 'Tell us which host this service check will be applied to'
+            self.fields['hostgroup_name'] = self.get_pynagField('hostgroup_name', required=False)
+            self.fields['hostgroup_name'].help_text = "If you specify any hostgroups, this service will be applied to all hosts in that hostgroup"
         else:
             field_name = "%s_name" % object_type
             self.fields[field_name] = self.get_pynagField(
                 field_name, required=True)
 
+    def clean(self):
+        cleaned_data = super(AddObjectForm, self).clean()
+        print self.pynag_object.object_type
+        if self.pynag_object.object_type == 'service':
+            host_name = cleaned_data.get('host_name')
+            hostgroup_name = cleaned_data.get('hostgroup_name')
+            if host_name in (None, 'None', '') and hostgroup_name in (None, 'None', ''):
+                raise forms.ValidationError("Please specify either hostgroup_name or host_name")
+            else:
+                print "everything is A OK"
+        return cleaned_data
+
     def clean_timeperiod_name(self):
         return self._clean_shortname()
 
@@ -709,9 +729,6 @@ class AddObjectForm(PynagForm):
     def clean_contactgroup_name(self):
         return self._clean_shortname()
 
-    def clean_hostgroup_name(self):
-        return self._clean_shortname()
-
     def clean_servicegroup_name(self):
         return self._clean_shortname()
 
@@ -721,6 +738,8 @@ class AddObjectForm(PynagForm):
     def clean_host_name(self):
         if self.pynag_object.object_type == 'service':
             value = self.cleaned_data['host_name']
+            if not value:
+                return None
             hosts = value.split(',')
             for i in hosts:
                 existing_hosts = Model.Host.objects.filter(host_name=i)
@@ -730,6 +749,20 @@ class AddObjectForm(PynagForm):
                 return smart_str(self.cleaned_data['host_name'])
         return self._clean_shortname()
 
+    def clean_hostgroup_name(self):
+        if self.pynag_object.object_type == 'service':
+            value = self.cleaned_data['hostgroup_name']
+            if value in (None, '', 'null'):
+                return None
+            groups = value.split(',')
+            for i in groups:
+                existing_hostgroups = Model.Hostgroup.objects.filter(hostgroup_name=i)
+                if not existing_hostgroups:
+                    raise forms.ValidationError(
+                        "Could not find hostgroup called '%s'" % (i))
+                return smart_str(self.cleaned_data['hostgroup_name'])
+        return self._clean_shortname()
+
     def _clean_shortname(self):
         """ Make sure shortname of a particular object does not exist.
 
