@@ -31,55 +31,22 @@ import pynag.Model
 
 from adagios import settings
 from adagios.objectbrowser.forms import *
+from adagios.views import adagios_decorator
 
 
+@adagios_decorator
 def home(request):
     return redirect('adagios')
 
 
-def list_objects(request, object_type=None, display_these_objects=None):
-    """Finds Pynag objects and returns them in a pretty list. search filter can be applied via querystring
-
-    Arguments:
-        object_type(str) : Only find pynag object of this type
-        display_these_objects([ObjectDefinition]) : Instead of searching, simply return these objects
-
-    """
-    c = {'messages': [], 'objects': [],
-         'object_type': object_type}                      # This hash is sent to our template
-    # Validate any potential search terms sent via querystring
-    search = {}
-    for k, v in request.GET.items():
-        k, v = str(k), str(v)
-        if k == 'object_type':
-            object_type = v
-        if v == 'None':
-            search[k] = None
-        else:
-            search[k] = v
-
-    # If a non-existent object_type is requested, lets display a warning
-    # Model.string_to_class contains a hash map that convert string value to
-    # its respective class definition
-    Pynag = Model.string_to_class.get(object_type, Model.ObjectDefinition)
-
-    # Lets decide if we want to get everything or apply a filter
-    if display_these_objects is not None:
-        c['objects'] = display_these_objects
-    elif not len(search):
-        c['objects'] = Pynag.objects.all
-    else:
-        c['objects'] = Pynag.objects.filter(**search)
-
-    return render_to_response('list_objects.html', c, context_instance=RequestContext(request))
-
-
+@adagios_decorator
 def list_object_types(request):
     """ Collects statistics about pynag objects and returns to template """
     c = {}
     return render_to_response('list_object_types.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def geek_edit(request, object_id):
     """ Function handles POST requests for the geek edit form """
     c = {}
@@ -126,6 +93,7 @@ def geek_edit(request, object_id):
     return HttpResponseRedirect(reverse('edit_object', kwargs={'object_id': o.get_id()}))
 
 
+@adagios_decorator
 def advanced_edit(request, object_id):
     """ Handles POST only requests for the "advanced" object edit form. """
     c = {}
@@ -168,73 +136,68 @@ def advanced_edit(request, object_id):
     return HttpResponseRedirect(reverse('edit_object', args=[o.get_id()]))
 
 
-def edit_object(request, object_id=None, object_type=None, shortname=None):
-    """ View details about one specific pynag object """
+@adagios_decorator
+def edit_object(request, object_id=None):
+    """ Brings up an edit dialog for one specific object.
+
+        If an object_id is specified, bring us to that exact object.
+
+        Otherwise we expect some search arguments to have been provided via querystring
+    """
     c = {}
     c.update(csrf(request))
-    c['messages'] = m = []
+    c['messages'] = []
     c['errors'] = []
-    c['nagios_url'] = settings.nagios_url
-    # Get our object
-    if object_id is not None:
-        # If object id was specified
-        try:
-            o = ObjectDefinition.objects.get_by_id(id=object_id)
-        except Exception, e:
-            # Not raising, handled by template
-            c['error_summary'] = 'Unable to get object'
-            c['error'] = e
-            return render_to_response('error.html', c, context_instance=RequestContext(request))
-    elif object_type is not None and shortname is None:
-        # Specifying only object_type indicates this is a new object
-        otype = Model.string_to_class.get(object_type, Model.ObjectDefinition)
-        o = otype()
-        c['form'] = PynagForm(pynag_object=o, initial=request.GET)
-    elif object_type is not None and shortname is not None:
-        # Its also valid to specify object type and shortname
-        # TODO: if multiple objects are found, display a list
-        try:
-            otype = Model.string_to_class.get(
-                object_type, Model.ObjectDefinition)
-            o = otype.objects.get_by_shortname(shortname)
-        except Exception, e:
-            # Not raising, handled by template
-            c['error_summary'] = 'Unable to get object'
-            c['error'] = e
-            return render_to_response('error.html', c, context_instance=RequestContext(request))
+    my_object = None  # This is where we store our item that we are editing
+
+    # If object_id was not provided, lets see if anything was given to us in a querystring
+    if not object_id:
+        objects = pynag.Model.ObjectDefinition.objects.filter(**request.GET)
+        if len(objects) == 1:
+            my_object = objects[0]
+        else:
+            return search_objects(request)
     else:
-        raise ValueError("Object not found")
+        try:
+            my_object = pynag.Model.ObjectDefinition.objects.get_by_id(object_id)
+        except KeyError:
+            c['error_summary'] = 'Could not find any object with id="%s" :/' % object_id
+            c['error_type'] = "object not found"
+            return render_to_response('error.html', c, context_instance=RequestContext(request))
 
     if request.method == 'POST':
         # User is posting data into our form
         c['form'] = PynagForm(
-            pynag_object=o, initial=o._original_attributes, data=request.POST)
+            pynag_object=my_object,
+            initial=my_object._original_attributes,
+            data=request.POST
+        )
         if c['form'].is_valid():
             try:
                 c['form'].save()
-                m.append("Object Saved to %s" % o['filename'])
-                return HttpResponseRedirect(reverse('edit_object', kwargs={'object_id': o.get_id()}))
+                c['messages'].append("Object Saved to %s" % my_object['filename'])
+                return HttpResponseRedirect(reverse('edit_object', kwargs={'object_id': my_object.get_id()}))
             except Exception, e:
                 c['errors'].append(e)
         else:
             c['errors'].append("Could not validate form input")
     if 'form' not in c:
-        c['form'] = PynagForm(pynag_object=o, initial=o._original_attributes)
-    c['my_object'] = o
+        c['form'] = PynagForm(pynag_object=my_object, initial=my_object._original_attributes)
+    c['my_object'] = my_object
     c['geek_edit'] = GeekEditObjectForm(
-        initial={'definition': o['meta']['raw_definition'], })
+        initial={'definition': my_object['meta']['raw_definition'], })
     c['advanced_form'] = AdvancedEditForm(
-        pynag_object=o, initial=o._original_attributes)
+        pynag_object=my_object, initial=my_object._original_attributes)
 
     try:
-        c['effective_hosts'] = o.get_effective_hosts()
+        c['effective_hosts'] = my_object.get_effective_hosts()
     except KeyError, e:
         c['errors'].append("Could not find host: %s" % str(e))
     except AttributeError:
         pass
 
     try:
-        c['effective_parents'] = o.get_effective_parents()
+        c['effective_parents'] = my_object.get_effective_parents()
     except KeyError, e:
         c['errors'].append("Could not find parent: %s" % str(e))
 
@@ -242,25 +205,25 @@ def edit_object(request, object_id=None, object_type=None, shortname=None):
     # to appropriate helper function
     if False:
         pass
-    elif o['object_type'] == 'servicegroup':
+    elif my_object['object_type'] == 'servicegroup':
         return _edit_servicegroup(request, c)
-    elif o['object_type'] == 'hostdependency':
+    elif my_object['object_type'] == 'hostdependency':
         return _edit_hostdependency(request, c)
-    elif o['object_type'] == 'service':
+    elif my_object['object_type'] == 'service':
         return _edit_service(request, c)
-    elif o['object_type'] == 'contactgroup':
+    elif my_object['object_type'] == 'contactgroup':
         return _edit_contactgroup(request, c)
-    elif o['object_type'] == 'hostgroup':
+    elif my_object['object_type'] == 'hostgroup':
         return _edit_hostgroup(request, c)
-    elif o['object_type'] == 'host':
+    elif my_object['object_type'] == 'host':
         return _edit_host(request, c)
-    elif o['object_type'] == 'contact':
+    elif my_object['object_type'] == 'contact':
         return _edit_contact(request, c)
-    elif o['object_type'] == 'command':
+    elif my_object['object_type'] == 'command':
         return _edit_command(request, c)
-    elif o['object_type'] == 'servicedependency':
+    elif my_object['object_type'] == 'servicedependency':
         return _edit_servicedependency(request, c)
-    elif o['object_type'] == 'timeperiod':
+    elif my_object['object_type'] == 'timeperiod':
         return _edit_timeperiod(request, c)
     else:
         return render_to_response('edit_object.html', c, context_instance=RequestContext(request))
@@ -476,6 +439,7 @@ def _edit_host(request, c):
     return render_to_response('edit_host.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def config_health(request):
     """ Display possible errors in your nagios config
     """
@@ -516,11 +480,12 @@ def config_health(request):
     s['Hosts without Service Checks'] = hosts_without_services
     if request.GET.has_key('show') and s.has_key(request.GET['show']):
         objects = s[request.GET['show']]
-        return list_objects(request, display_these_objects=objects)
+        return search_objects(request, objects=objects)
     else:
         return render_to_response('suggestions.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def show_plugins(request):
     """ Finds all command_line arguments, and shows missing plugins """
     c = {}
@@ -555,6 +520,7 @@ def show_plugins(request):
     return render_to_response('show_plugins.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def edit_nagios_cfg(request):
     """ This views is made to make modifications to nagios.cfg
     """
@@ -591,6 +557,7 @@ def edit_nagios_cfg(request):
     return render_to_response('edit_configfile.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def bulk_edit(request):
     """ Edit multiple objects with one post """
     c = {}
@@ -624,7 +591,7 @@ def bulk_edit(request):
 
     return render_to_response('bulk_edit.html', c, context_instance=RequestContext(request))
 
-
+@adagios_decorator
 def bulk_delete(request):
     """ Edit delete multiple objects with one post """
     c = {}
@@ -638,8 +605,12 @@ def bulk_delete(request):
     # object_type=shortname
     # i.e. timeperiod=24x7, timeperiod=workhours
     for i in _querystring_to_objects(request.GET or request.POST):
-        obj = pynag.Model.string_to_class[i.object_type].objects.get_by_shortname(i.description)
-        objects.append(obj)
+        try:
+            obj = pynag.Model.string_to_class[i.object_type].objects.get_by_shortname(i.description)
+            if obj not in objects:
+                objects.append(obj)
+        except KeyError:
+            c['errors'].append("Could not find %s '%s' Maybe it has already been deleted." % (i.object_type, i.description))
     if request.method == "GET" and len(objects) == 1:
         return HttpResponseRedirect(reverse('delete_object', kwargs={'object_id': objects[0].get_id()}), )
 
@@ -650,7 +621,8 @@ def bulk_delete(request):
             if i.startswith('change_'):
                 my_id = i[len('change_'):]
                 my_obj = ObjectDefinition.objects.get_by_id(my_id)
-                objects.append(my_obj)
+                if my_obj not in objects:
+                    objects.append(my_obj)
 
         c['form'] = BulkDeleteForm(objects=objects, data=request.POST)
         if c['form'].is_valid():
@@ -665,7 +637,7 @@ def bulk_delete(request):
 
     return render_to_response('bulk_delete.html', c, context_instance=RequestContext(request))
 
-
+@adagios_decorator
 def bulk_copy(request):
     """ Copy multiple objects with one post """
     c = {}
@@ -679,9 +651,12 @@ def bulk_copy(request):
     # object_type=shortname
     # i.e. timeperiod=24x7, timeperiod=workhours
     for i in _querystring_to_objects(request.GET or request.POST):
-        obj = pynag.Model.string_to_class[i.object_type].objects.get_by_shortname(i.description)
-        objects.append(obj)
-
+        try:
+            obj = pynag.Model.string_to_class[i.object_type].objects.get_by_shortname(i.description)
+            if obj not in objects:
+                objects.append(obj)
+        except KeyError:
+            c['errors'].append("Could not find %s '%s'" % (i.object_type, i.description))
     if request.method == "GET" and len(objects) == 1:
         return HttpResponseRedirect(reverse('copy_object', kwargs={'object_id': objects[0].get_id()}), )
     elif request.method == "POST":
@@ -691,7 +666,8 @@ def bulk_copy(request):
             if i.startswith('change_'):
                 my_id = i[len('change_'):]
                 my_obj = ObjectDefinition.objects.get_by_id(my_id)
-                objects.append(my_obj)
+                if my_obj not in objects:
+                    objects.append(my_obj)
 
         c['form'] = BulkCopyForm(objects=objects, data=request.POST)
         if c['form'].is_valid():
@@ -706,7 +682,7 @@ def bulk_copy(request):
 
     return render_to_response('bulk_copy.html', c, context_instance=RequestContext(request))
 
-
+@adagios_decorator
 def delete_object_by_shortname(request, object_type, shortname):
     """ Same as delete_object() but uses object type and shortname instead of object_id
     """
@@ -714,7 +690,7 @@ def delete_object_by_shortname(request, object_type, shortname):
     my_obj = obj_type.objects.get_by_shortname(shortname)
     return delete_object(request, object_id=my_obj.get_id())
 
-
+@adagios_decorator
 def delete_object(request, object_id):
     """ View to Delete a single object definition """
     c = {}
@@ -735,6 +711,7 @@ def delete_object(request, object_id):
     return render_to_response('delete_object.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def copy_object(request, object_id):
     """ View to Copy a single object definition """
     c = {}
@@ -757,6 +734,7 @@ def copy_object(request, object_id):
     return render_to_response('copy_object.html', c, context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def add_object(request, object_type):
     """ Friendly wizard on adding a new object of any particular type
     """
@@ -845,6 +823,7 @@ def _querydict_to_objects(request, raise_on_not_found=False):
     return result
 
 
+@adagios_decorator
 def add_to_group(request, group_type=None, group_name=''):
     """ Add one or more objects into a group
     """
@@ -876,6 +855,7 @@ def add_to_group(request, group_type=None, group_name=''):
     return render_to_response('add_to_group.html', locals(), context_instance=RequestContext(request))
 
 
+@adagios_decorator
 def edit_all(request, object_type, attribute_name):
     """  Edit many objects at once, changing only a single attribute
 
@@ -888,3 +868,59 @@ def edit_all(request, object_type, attribute_name):
     objects = map(lambda x: (x.get_shortname, x.get(attribute_name)), objects)
     return render_to_response('edit_all.html', locals(), context_instance=RequestContext(request))
 
+
+
+@adagios_decorator
+def search_objects(request, objects=None):
+    """ Displays a list of pynag objects, search parameters can be entered via querystring
+
+        Arguments:
+            objects -- List of pynag objects to show. If it is not set,
+                    -- We will use querystring instead as search arguments
+        example:
+         /adagios/objectbrowser/search?object_type=host&host_name__startswith=foo
+
+
+    """
+    messages = []
+    errors = []
+    if not objects:
+        objects = pynag.Model.ObjectDefinition.objects.filter(**request.GET)
+
+    # A special case, if no object was found, lets check if user was looking for a service
+    # With its host_name / service_description pair, and the service is applied to hostgroup instead
+    if not objects and request.GET.get('object_type') == 'service':
+        host_name = request.GET.get('host_name')
+        service_description = request.GET.get('service_description')
+        shortname = request.GET.get('shortname')
+
+        # If shortname was provided instead of host_name / service_description
+        if not host_name and not service_description and shortname:
+            host_name, service_description = shortname.split('/')
+
+        # If at this point we have found some objects, then lets do a special workaround
+        services = pynag.Model.Service.objects.filter(service_description=service_description, hostgroup_name__exists=True)
+        errors.append('be careful')
+
+
+    return render_to_response('search_objects.html', locals(), context_instance=RequestContext(request))
+
+
+@adagios_decorator
+def copy_and_edit_object(request, object_id):
+    """ Create a new object, and open up an edit dialog for it.
+
+    If object_id is provided, that object will be copied into this one.
+    """
+    kwargs = {}
+    for k, v in request.GET.items():
+        if v in ('', None, 'None'):
+            v = None
+        kwargs[k] = v
+    o = pynag.Model.ObjectDefinition.objects.get_by_id(object_id)
+    o = o.copy(**kwargs)
+    o = pynag.Model.ObjectDefinition.objects.filter(shortname=o.get_shortname(), object_type=o.object_type)[0]
+
+    return HttpResponseRedirect(reverse('edit_object', kwargs={'object_id': o.get_id()}))
+
+
