@@ -116,6 +116,7 @@ TEMPLATE_CONTEXT_PROCESSORS = ('adagios.context_processors.on_page_load',
     "django.core.context_processors.i18n",
     "django.core.context_processors.media",
     "django.core.context_processors.static",
+    "django.core.context_processors.request",
     "django.contrib.messages.context_processors.messages")
 
  
@@ -127,13 +128,14 @@ nagios_config=None # Sensible default is "/etc/nagios/nagios.cfg"
 nagios_url="/nagios"
 nagios_init_script = "/etc/init.d/nagios"
 nagios_binary = "/usr/bin/nagios"
+livestatus_path = None
 enable_githandler=False
 enable_loghandler = False
 enable_authorization = False
 enable_status_view = True
-enable_pages_view = True
 enable_bi = True
 contrib_dir = "/var/lib/adagios/contrib/"
+serverside_includes = "/etc/adagios/ssi"
 escape_html_tags = True
 warn_if_selinux_is_active = True
 destination_directory="/etc/nagios/adagios/"
@@ -144,9 +146,8 @@ include=""
 django_secret_key = ""
 map_center = "64.119595,-21.655426"
 map_zoom = "10"
-
-# pages module, path to extra pages the user can upload
-extra_pages = "/etc/adagios/pages.d"
+title_prefix = "Adagios - "
+auto_reload = False
 
 plugins = {}
 
@@ -191,21 +192,21 @@ if not django_secret_key:
     chars = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'
     SECRET_KEY = get_random_string(50, chars)
     try:
-        fh = open(adagios_configfile, "a")
-        fh.write("\n# Automaticly generated secret_key\ndjango_secret_key = '%s'\n"
-            % SECRET_KEY)
-        fh.close()
+        data = "\n# Automaticly generated secret_key\ndjango_secret_key = '%s'\n" % SECRET_KEY
+        with open(adagios_configfile, "a") as config_fh:
+            config_fh.write(data)
     except Exception, e:
-                raise Exception("Unable to save generated django_secret_key: %s" % e)
+        print("ERROR: Got %s while trying to save django secret_key in %s" % (type(e), adagios_configfile))
+
 else:
     SECRET_KEY = django_secret_key
 
+ALLOWED_INCLUDE_ROOTS = (serverside_includes,)
+
 if enable_status_view:
-  plugins['status'] = 'adagios.status'
-if enable_pages_view:
-  plugins['pages'] = 'adagios.pages'
+    plugins['status'] = 'adagios.status'
 if enable_bi:
-  plugins['bi'] = 'adagios.bi'
+    plugins['bi'] = 'adagios.bi'
 
 for k,v in plugins.items():
     INSTALLED_APPS.append( v )
