@@ -9,30 +9,27 @@ with status of Nagios.
 import time
 import pynag.Control.Command
 import pynag.Model
-import django.core.mail
 import pynag.Utils
 import adagios.status.utils
 import pynag.Parsers
 import collections
-from pynag.Utils import PynagError
 
 
-def hosts(request, fields=None, *args, **kwargs):
+def hosts(request, fields=None, **kwargs):
     """ Get List of hosts. Any parameters will be passed straight throught to pynag.Utils.grep()
 
         Arguments:
             fields -- If specified, a list of attributes to return. If unspecified, all fields are returned.
 
-            Any *args will be passed to livestatus directly
             Any **kwargs will be treated as a pynag.Utils.grep()-style filter
     """
-    return adagios.status.utils.get_hosts(request=request, fields=fields, *args, **kwargs)
+    return adagios.status.utils.get_hosts(request=request, fields=fields, **kwargs)
 
 
-def services(request, fields=None, *args, **kwargs):
+def services(request, fields=None, **kwargs):
     """ Similar to hosts(), is a wrapper around adagios.status.utils.get_services()
     """
-    return adagios.status.utils.get_services(request=request, fields=fields, *args, **kwargs)
+    return adagios.status.utils.get_services(request=request, fields=fields, **kwargs)
 
 def services_dt(fields=None, *args, **kwargs):
     """ Similar to hosts(), is a wrapper around adagios.status.utils.get_services()
@@ -40,26 +37,51 @@ def services_dt(fields=None, *args, **kwargs):
     return adagios.status.utils.get_services(fields=fields, *args, **kwargs)
 
 
-def contacts(fields=None, *args, **kwargs):
+def contacts(request, fields=None, *args, **kwargs):
     """ Wrapper around pynag.Parsers.mk_livestatus.get_contacts()
     """
-    l = pynag.Parsers.mk_livestatus(
-        nagios_cfg_file=adagios.settings.nagios_config)
+    l = adagios.status.utils.livestatus(request)
     return l.get_contacts(*args, **kwargs)
 
 
-def emails(*args, **kwargs):
+def emails(request, *args, **kwargs):
     """ Returns a list of all emails of all contacts
     """
-    l = pynag.Parsers.mk_livestatus(
-        nagios_cfg_file=adagios.settings.nagios_config)
+    l = adagios.status.utils.livestatus(request)
     return map(lambda x: x['email'], l.get_contacts('Filter: email !='))
 
 
-def acknowledge(host_name, service_description=None, sticky=1, notify=1, persistent=0, author='adagios', comment='acknowledged by Adagios'):
-    """ Acknowledge one single host or service check
+def acknowledge_many(hostlist, servicelist, sticky=1, notify=1, persistent=0, author="adagios", comment="acknowledged by Adagios"):
+    """ Same as acknowledge, but for acknowledge on many hosts services at a time.
 
+     Arguments:
+        hostlist    -- string in the format of host1;host2;host3
+        servicelist -- string in the format of host1,service1;host2,service2
     """
+    items = []
+    for i in hostlist.split(';'):
+        if not i: continue
+        items.append((i, None))
+
+    for i in servicelist.split(';'):
+        if not i: continue
+        host_name,service_description = i.split(',')
+        items.append((host_name, service_description))
+    for i in items:
+        acknowledge(
+                host_name=i[0],
+                service_description=i[1],
+                sticky=sticky,
+                notify=notify,
+                persistent=persistent,
+                author=author,
+                comment=comment
+        )
+    return "Success"
+
+
+def acknowledge(host_name, service_description=None, sticky=1, notify=1, persistent=0, author='adagios', comment='acknowledged by Adagios'):
+    """ Acknowledge one single host or service check """
     if service_description in (None, '', u'', '_HOST_'):
         pynag.Control.Command.acknowledge_host_problem(host_name=host_name,
                                                        sticky=sticky,
@@ -79,6 +101,45 @@ def acknowledge(host_name, service_description=None, sticky=1, notify=1, persist
                                                       )
 
 
+def downtime_many(hostlist, servicelist, hostgrouplist, start_time=None, end_time=None, fixed=1, trigger_id=0, duration=7200, author='adagios', comment='Downtime scheduled by adagios', all_services_on_host=False, hostgroup_name=None):
+    """ Same as downtime, but for acknowledge on many hosts services at a time.
+
+     Arguments:
+        hostlist    -- string in the format of host1;host2;host3
+        hostgrouplist -- string in the format of hostgroup1;hostgroup2;hostgroup3
+        servicelist -- string in the format of host1,service1;host2,service2
+    """
+    items = []
+    for i in hostlist.split(';'):
+        if not i: continue
+        items.append((i, None, None))
+    for i in hostgrouplist.split(';'):
+        if not i: continue
+        items.append((None, None, i))
+
+    for i in servicelist.split(';'):
+        if not i: continue
+        host_name, service_description = i.split(',')
+        items.append((host_name, service_description, None))
+    for i in items:
+        host_name = i[0]
+        service_description = i[1]
+        hostgroup_name = i[2]
+        downtime(
+            host_name=host_name,
+            service_description=service_description,
+            start_time=start_time,
+            end_time=end_time,
+            fixed=fixed,
+            trigger_id=trigger_id,
+            duration=duration,
+            author=author,
+            comment=comment,
+            all_services_on_host=all_services_on_host,
+            hostgroup_name=hostgroup_name
+        )
+
+
 def downtime(host_name=None, service_description=None, start_time=None, end_time=None, fixed=1, trigger_id=0, duration=7200, author='adagios', comment='Downtime scheduled by adagios', all_services_on_host=False, hostgroup_name=None):
     """ Schedule downtime for a host or a service """
     if fixed in (1, '1') and start_time in (None, ''):
@@ -162,16 +223,41 @@ def downtime(host_name=None, service_description=None, start_time=None, end_time
             comment=comment,
         )
 
+import adagios.utils
 
-def reschedule(host_name, service_description=None, check_time=None, wait=0):
+
+def reschedule_many(request, hostlist, servicelist, check_time=None, **kwargs):
+    """ Same as reschedule() but takes a list of hosts/services as input
+
+    Arguments:
+      hostlist    -- semicolon seperated list of hosts to schedule checks for. Same as multiple calls with host_name=
+      servicelist -- Same as hostlist but for services. Format is: host_name,service_description;host_name,service_description
+    """
+    #task = adagios.utils.Task()
+    #WaitCondition = "last_check > %s" % int(time.time()- 1)
+    for i in hostlist.split(';'):
+        if not i: continue
+        reschedule(request, host_name=i, service_description=None, check_time=check_time)
+        #task.add(wait, 'hosts', i, WaitCondition)
+    for i in servicelist.split(';'):
+        if not i: continue
+        host_name,service_description = i.split(',')
+        reschedule(request, host_name=host_name, service_description=service_description, check_time=check_time)
+        #WaitObject = "{h};{s}".format(h=host_name, s=service_description)
+        #task.add(wait, 'services', WaitObject, WaitCondition)
+    return {'message': "command sent successfully"}
+
+
+def reschedule(request, host_name=None, service_description=None, check_time=None, wait=0, hostlist='', servicelist=''):
     """ Reschedule a check of this service/host
 
     Arguments:
       host_name -- Name of the host
       service_description -- Name of the service check. If left empty, host check will be rescheduled
       check_time -- timestamp of when to execute this check, if left empty, execute right now
-      wait -- If set to 1, function will not run until check has been rescheduled
+      wait -- If set to 1, function will not return until check has been rescheduled
     """
+
     if check_time is None or check_time is '':
         check_time = time.time()
     if service_description in (None, '', u'', '_HOST_', 'undefined'):
@@ -179,7 +265,7 @@ def reschedule(host_name, service_description=None, check_time=None, wait=0):
         pynag.Control.Command.schedule_forced_host_check(
             host_name=host_name, check_time=check_time)
         if wait == "1":
-            livestatus = pynag.Parsers.mk_livestatus()
+            livestatus = adagios.status.utils.livestatus(request)
             livestatus.query("GET hosts",
                              "WaitObject: %s " % host_name,
                              "WaitCondition: last_check > %s" % check_time,
@@ -190,7 +276,7 @@ def reschedule(host_name, service_description=None, check_time=None, wait=0):
         pynag.Control.Command.schedule_forced_svc_check(
             host_name=host_name, service_description=service_description, check_time=check_time)
         if wait == "1":
-            livestatus = pynag.Parsers.mk_livestatus()
+            livestatus = adagios.status.utils.livestatus(request)
             livestatus.query("GET services",
                              "WaitObject: %s %s" % (
                                  host_name, service_description),
@@ -249,9 +335,9 @@ def edit(object_type, short_name, attribute_name, new_value):
     return str(my_obj)
 
 
-def get_map_data(host_name=None):
+def get_map_data(request, host_name=None):
     """ Returns a list of (host_name,2d_coords). If host_name is provided, returns a list with only that host """
-    livestatus = pynag.Parsers.mk_livestatus()
+    livestatus = adagios.status.utils.livestatus(request)
     all_hosts = livestatus.query('GET hosts', )
     hosts_with_coordinates = pynag.Model.Host.objects.filter(
         **{'2d_coords__exists': True})
@@ -312,22 +398,21 @@ def change_host_coordinates(host_name, latitude, longitude):
     host.save()
 
 
-def autocomplete(q):
+def autocomplete(request, q):
     """ Returns a list of {'hosts':[], 'hostgroups':[],'services':[]} matching search query q
     """
     if q is None:
         q = ''
     result = {}
-    hosts = pynag.Model.Host.objects.filter(host_name__contains=q)
-    services = pynag.Model.Service.objects.filter(
-        service_description__contains=q)
-    hostgroups = pynag.Model.Hostgroup.objects.filter(
-        hostgroup_name__contains=q)
-    result['hosts'] = sorted(set(map(lambda x: x.host_name, hosts)))
-    result['hostgroups'] = sorted(
-        set(map(lambda x: x.hostgroup_name, hostgroups)))
-    result['services'] = sorted(
-        set(map(lambda x: x.service_description, services)))
+
+    hosts = adagios.status.utils.get_hosts(request, host_name__contains=q)
+    services = adagios.status.utils.get_services(request, service_description__contains=q)
+    hostgroups = adagios.status.utils.get_hostgroups(request, hostgroup_name__contains=q)
+
+    result['hosts'] = sorted(set(map(lambda x: x['name'], hosts)))
+    result['hostgroups'] = sorted(set(map(lambda x: x['name'], hostgroups)))
+    result['services'] = sorted(set(map(lambda x: x['description'], services)))
+
     return result
 
 
@@ -386,7 +471,7 @@ def log_entries(*args, **kwargs):
     return l.get_log_entries(*args, **kwargs)
 
 
-def state_history(start_time=None, end_time=None, host_name=None, service_description=None):
+def state_history(start_time=None, end_time=None, object_type=None, host_name=None, service_description=None, hostgroup_name=None):
     """ Returns a list of dicts, with the state history of hosts and services. Parameters behaves similar to get_log_entries
 
     """
@@ -398,10 +483,39 @@ def state_history(start_time=None, end_time=None, host_name=None, service_descri
         host_name = None
     if service_description == '':
         service_description = None
-
     l = pynag.Parsers.LogFiles()
-    return l.get_state_history(start_time=start_time, end_time=end_time, host_name=host_name, service_description=service_description)
+    log_entries = l.get_state_history(start_time=start_time, end_time=end_time, host_name=host_name, service_description=service_description)
+    if object_type == 'host' or object_type == 'service':
+        pass
+    elif object_type == 'hostgroup':
+        hg = pynag.Model.Hostgroup.objects.get_by_shortname(hostgroup_name)
+        hosts = hg.get_effective_hosts()
+        hostnames = map(lambda x: x.host_name, hosts)
+        log_entries = filter(lambda x: x['host_name'] in hostnames, log_entries)
+    else:
+        raise Exception("Unsupported object type: %s" % object_type)
 
+    # Add some css-hints for and duration of each state history entry as percent of duration
+    # this is used by all views that have state history and on top of it a progress bar which shows
+    # Up/downtime totals.
+    c = {'log': log_entries }
+    if len(c['log']) > 0:
+        log = c['log']
+        c['start_time'] = start_time = log[0]['time']
+        c['end_time'] = log[-1]['time']
+        now = time.time()
+
+        total_duration = now - start_time
+        css_hint = {}
+        css_hint[0] = 'success'
+        css_hint[1] = 'warning'
+        css_hint[2] = 'danger'
+        css_hint[3] = 'info'
+        for i in log:
+            i['duration_percent'] = 100 * i['duration'] / total_duration
+            i['bootstrap_status'] = css_hint[i['state']]
+
+    return log_entries
 
 def _get_service_model(host_name, service_description=None):
     """ Return one pynag.Model.Service object for one specific service as seen
@@ -425,18 +539,30 @@ def _get_service_model(host_name, service_description=None):
 
 
 def command_line(host_name, service_description=None):
-    """ Returns effective command line for a host or a service (i.e. resolves check_command)
-    """
+    """ Returns effective command line for a host or a service (i.e. resolves check_command) """
     try:
-        if service_description in (None, '', '_HOST_'):
-            obj = pynag.Model.Host.objects.get_by_shortname(host_name)
-        else:
-            obj = _get_service_model(host_name, service_description)
+        obj = _get_host_or_service(host_name, service_description)
         return obj.get_effective_command_line(host_name=host_name)
     except KeyError:
         return "Could not resolve commandline. Object not found"
 
 
+def _get_host_or_service(host_name, service_description=None):
+    """ Return a pynag.Model.Host or pynag.Model.Service or raise exception if none are found """
+    host = pynag.Model.Host.objects.get_by_shortname(host_name)
+    if not service_description:
+        return host
+    else:
+        search_result = pynag.Model.Service.objects.filter(host_name=host_name, service_description=service_description)
+        if search_result:
+            return search_result[0]
+        # If no services were found, the service might be applied to a hostgroup
+        for service in host.get_effective_services():
+            if service.service_description == service_description:
+                return service
+    raise KeyError("Object not found")
+
+
 def update_check_command(host_name, service_description=None, **kwargs):
     """ Saves all custom variables of a given service
     """
@@ -447,7 +573,7 @@ def update_check_command(host_name, service_description=None, **kwargs):
             else:
                 obj = pynag.Model.Service.objects.get_by_shortname(
                     "%s/%s" % (host_name, service_description))
-            if k.startswith("$_SERVICE") or k.startswith('$ARG'):
+            if k.startswith("$_SERVICE") or k.startswith('$ARG') or k.startswith('$_HOST'):
                 obj.set_macro(k, v)
                 obj.save()
         return "Object saved"
@@ -462,10 +588,10 @@ def get_business_process_names():
     return map(lambda x: x.name, adagios.businessprocess.get_all_processes())
 
 
-def get(object_type, *args, **kwargs):
+def get(request, object_type, *args, **kwargs):
     livestatus_arguments = pynag.Utils.grep_to_livestatus(*args, **kwargs)
     if not object_type.endswith('s'):
-        object_type = object_type + 's'
+        object_type += 's'
     if 'name__contains' in kwargs and object_type == 'services':
         name = str(kwargs['name__contains'])
         livestatus_arguments = filter(
@@ -473,7 +599,7 @@ def get(object_type, *args, **kwargs):
         livestatus_arguments.append('Filter: host_name ~ %s' % name)
         livestatus_arguments.append('Filter: description ~ %s' % name)
         livestatus_arguments.append('Or: 2')
-    livestatus = pynag.Parsers.mk_livestatus()
+    livestatus = adagios.status.utils.livestatus(request)
     results = livestatus.query('GET %s' % object_type, *livestatus_arguments)
 
     if object_type == 'service':
@@ -506,14 +632,14 @@ def get_business_process(process_name=None, process_type=None):
     return result
 
 
-def remove_downtime(host_name, service_description=None, downtime_id=None):
+def remove_downtime(request, host_name, service_description=None, downtime_id=None):
     """ Remove downtime for one specific host or service """
     downtimes_to_remove = []
     # If downtime_id is not provided, remove all downtimes of that service or host
     if downtime_id:
         downtimes_to_remove.append(downtime_id)
     else:
-        livestatus = pynag.Parsers.mk_livestatus(nagios_cfg_file=adagios.settings.nagios_config)
+        livestatus = adagios.status.utils.livestatus(request)
         query_parameters = []
         query_parameters.append('GET downtimes')
         query_parameters.append('Filter: host_name = {host_name}'.format(**locals()))
@@ -578,6 +704,80 @@ def submit_check_result(request, host_name, service_description=None, autocreate
     return result
 
 
-def statistics(request):
+def statistics(request, **kwargs):
     """ Returns a dict with various statistics on status data. """
-    return adagios.status.utils.get_statistics(request)
\ No newline at end of file
+    return adagios.status.utils.get_statistics(request, **kwargs)
+
+
+def metrics(request, **kwargs):
+    """ Returns a list of dicts which contain service perfdata metrics
+    """
+    result = []
+    fields = "host_name description perf_data state host_state".split()
+    services = adagios.status.utils.get_services(request, fields=fields, **kwargs)
+    for service in services:
+        metrics = pynag.Utils.PerfData(service['perf_data']).metrics
+        metrics = filter(lambda x: x.is_valid(), metrics)
+        for metric in metrics:
+            metric_dict = {
+                'host_name': service['host_name'],
+                'service_description': service['description'],
+                'state': service['state'],
+                'host_state': service['host_state'],
+                'label': metric.label,
+                'value': metric.value,
+                'uom': metric.uom,
+                'warn': metric.warn,
+                'crit': metric.crit,
+                'min': metric.min,
+                'max': metric.max,
+            }
+            result.append(metric_dict)
+    return result
+
+def metric_names(request, **kwargs):
+    """ Returns the names of all perfdata metrics that match selected request """
+    metric_names = set()
+    fields = "host_name description perf_data state host_state".split()
+    services = adagios.status.utils.get_services(request, fields=fields, **kwargs)
+    for service in services:
+        metrics = pynag.Utils.PerfData(service['perf_data']).metrics
+        metrics = filter(lambda x: x.is_valid(), metrics)
+        for metric in metrics:
+            metric_names.add(metric.label)
+
+    result = {
+        'services that match filter': len(services),
+        'filter': kwargs,
+        'metric_names': sorted(list(metric_names)),
+    }
+    return result
+
+def wait(table, WaitObject, WaitCondition=None, WaitTrigger='check', **kwargs):
+    print "Lets wait for", locals()
+    if not WaitCondition:
+        WaitCondition = "last_check > %s" % int(time.time()-1)
+    livestatus = adagios.status.utils.livestatus(None)
+    print "livestatus ok"
+    result = livestatus.get(table, 'Stats: state != 999', WaitObject=WaitObject, WaitCondition=WaitCondition, WaitTrigger=WaitTrigger, **kwargs)
+    print "ok no more waiting for ", WaitObject
+    return result
+
+
+def wait_many(hostlist, servicelist, WaitCondition=None, WaitTrigger='check', **kwargs):
+    if not WaitCondition:
+        WaitCondition = "last_check > %s" % int(time.time()-1)
+    livestatus = adagios.status.utils.livestatus(None)
+    for host in hostlist.split(';'):
+        if not host:
+            continue
+        WaitObject = host
+        livestatus.get('hosts', WaitObject=WaitObject, WaitCondition=WaitCondition, WaitTrigger=WaitTrigger, **kwargs)
+        print WaitObject
+    for service in servicelist.split(';'):
+        if not service:
+            continue
+        WaitObject = service.replace(',', ';')
+        livestatus.get('services', WaitObject=WaitObject, WaitCondition=WaitCondition, WaitTrigger=WaitTrigger, **kwargs)
+        print WaitObject
+
