@@ -20,12 +20,17 @@ def livestatus(request):
     """ Returns a new pynag.Parsers.mk_livestatus() object with authauser automatically set from request.META['remoteuser']
     """
 
-    if adagios.settings.enable_authorization == True:
+    if request == None:
+        authuser = None
+    elif adagios.settings.enable_authorization == True:
         authuser = request.META.get('REMOTE_USER', None)
     else:
         authuser = None
+
     livestatus = pynag.Parsers.mk_livestatus(
-        nagios_cfg_file=adagios.settings.nagios_config, authuser=authuser)
+        nagios_cfg_file=adagios.settings.nagios_config,
+        livestatus_socket_path=adagios.settings.livestatus_path,
+        authuser=authuser)
     return livestatus
 
 
@@ -35,6 +40,12 @@ def query(request, *args, **kwargs):
     return l.query(*args, **kwargs)
 
 
+def get_hostgroups(request, *args, **kwargs):
+    """ Get a list of hostgroups from mk_livestatus
+    """
+    l = livestatus(request)
+    return l.get_hostgroups(*args, **kwargs)
+
 def get_hosts(request, tags=None, fields=None, *args, **kwargs):
     """ Get a list of hosts from mk_livestatus
 
@@ -59,11 +70,17 @@ def get_hosts(request, tags=None, fields=None, *args, **kwargs):
     else:
         q = []
 
+    # Often search filters include description, which we will skip
+    kwargs.pop('description', None)
+
+    if 'host_state' in kwargs:
+        kwargs['state'] = kwargs.pop('host_state')
+
     # If keyword "unhandled" is in kwargs, then we will fetch unhandled
-    # services only
+    # hosts only
     if 'unhandled' in kwargs:
         del kwargs['unhandled']
-        kwargs['state__isnot'] = 0
+        kwargs['state'] = 1
         kwargs['acknowledged'] = 0
         kwargs['scheduled_downtime_depth'] = 0
         #kwargs['host_scheduled_downtime_depth'] = 0
@@ -121,7 +138,6 @@ def get_hosts(request, tags=None, fields=None, *args, **kwargs):
             except ZeroDivisionError:
                 host['health'] = 'n/a'
         except Exception:
-            host['num_problems'] = 'n/a'
             pass
 
     # Sort by host and service status
@@ -168,6 +184,7 @@ def get_services(request=None, tags=None, fields=None, *args, **kwargs):
         kwargs['scheduled_downtime_depth'] = 0
         kwargs['host_scheduled_downtime_depth'] = 0
         kwargs['host_acknowledged'] = 0
+        kwargs['host_state'] = 0
     arguments = pynag.Utils.grep_to_livestatus(*args, **kwargs)
 
     # If q was added, it is a fuzzy filter on services
@@ -226,16 +243,17 @@ def get_services(request=None, tags=None, fields=None, *args, **kwargs):
     return result
 
 
-def get_statistics(request):
+def get_statistics(request, *args, **kwargs):
     """ Return a list of dict. That contains various statistics from mk_livestatus (like service totals and host totals)
     """
     c = {}
     l = livestatus(request)
+    arguments = pynag.Utils.grep_to_livestatus(*args, **kwargs)
     # Get host/service totals as an array of [ok,warn,crit,unknown]
     c['service_totals'] = l.query('GET services', 'Stats: state = 0',
-                                  'Stats: state = 1', 'Stats: state = 2', 'Stats: state = 3', columns=False)
+                                  'Stats: state = 1', 'Stats: state = 2', 'Stats: state = 3', *arguments)
     c['host_totals'] = l.query(
-        'GET hosts', 'Stats: state = 0', 'Stats: state = 1', 'Stats: state = 2', columns=False)
+        'GET hosts', 'Stats: state = 0', 'Stats: state = 1', 'Stats: state = 2', *arguments)
 
     # Get total number of host/services
     c['total_hosts'] = sum(c['host_totals'])
@@ -260,26 +278,27 @@ def get_statistics(request):
                                       'Filter: scheduled_downtime_depth = 0',
                                       'Filter: host_state = 0',
                                       'Stats: state > 0',
-                                      columns=False
+                                      *arguments
                                       )[0]
     c['unhandled_hosts'] = l.query('GET hosts',
                                    'Filter: acknowledged = 0',
                                    'Filter: scheduled_downtime_depth = 0',
-                                   'Stats: state > 0',
-                                   columns=False,
+                                   'Stats: state = 1',
+                                   *arguments
                                    )[0]
+
     c['total_unhandled_network_problems'] = l.query('GET hosts',
                                                     'Filter: acknowledged = 0',
                                                     'Filter: scheduled_downtime_depth = 0',
                                                     'Filter: childs != ',
-                                                    'Stats: state > 0',
-                                                    columns=False
+                                                    'Stats: state = 1',
+                                                    *arguments
                                                     )[0]
     tmp = l.query('GET hosts',
                   'Filter: childs != ',
                   'Stats: state >= 0',
                   'Stats: state > 0',
-                  columns=False
+                  *arguments
                   )
     c['total_network_parents'], c['total_network_problems'] = tmp
     return c
@@ -600,3 +619,65 @@ def get_business_process(process_type, name):
         return c
     else:
         raise Exception("Business process of type %s not found" % process_type)
+
+
+
+
+def grep_to_livestatus(object_type, *args, **kwargs):
+    """ Take querystring parameters from django request object, and returns list of livestatus queries
+
+        Should support both hosts and services.
+
+        It does minimal support for views have hosts and services in same view and user wants to
+        enter some querystring parameters for both.
+
+    """
+    result = []
+    for key in kwargs:
+        if hasattr(kwargs, 'getlist'):
+            values = kwargs(key)
+        else:
+            values = [kwargs.get(key)]
+
+        if object_type == 'host' and key.startswith('service_'):
+            continue
+        if object_type == 'host' and key == 'description':
+            continue
+        if object_type == 'host' and key in ('host_scheduled_downtime_depth', 'host_acknowledged', 'host_state'):
+            key = key[len('host_'):]
+        if object_type == 'service' and key in ('service_state', 'service_description'):
+            key = key[len('service_'):]
+
+        if object_type == 'service' and key == 'unhandled':
+            tmp = {}
+            tmp['state__isnot'] = 0
+            tmp['acknowledged'] = 0
+            tmp['scheduled_downtime_depth'] = 0
+            tmp['host_scheduled_downtime_depth'] = 0
+            tmp['host_acknowledged'] = 0
+            tmp['host_state'] = 0
+            result += pynag.Utils.grep_to_livestatus(**kwargs)
+        elif object_type == 'host' and key == 'unhandled':
+            tmp = {}
+            tmp['state__isnot'] = 0
+            tmp['acknowledged'] = 0
+            tmp['scheduled_downtime_depth'] = 0
+        elif object_type == 'host' and key == 'q':
+            for i in values:
+                result.append('Filter: name ~~ %s' % i)
+                result.append('Filter: address ~~ %s' % i)
+                result.append('Filter: plugin_output ~~ %s' % i)
+                result.append('Or: 3')
+        elif object_type == 'service' and key == 'q':
+            for i in values:
+                result.append('Filter: host_name ~~ %s' % i)
+                result.append('Filter: description ~~ %s' % i)
+                result.append('Filter: plugin_output ~~ %s' % i)
+                result.append('Filter: host_address ~~ %s' % i)
+                result.append('Or: 4')
+        else:
+            for value in values:
+                result += pynag.Utils.grep_to_livestatus(**{key: value})
+
+    return list(args) + result
+
